<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\CategorieFaq\CreateCategorieFaqRequestAction;
use App\Controller\CategorieFaq\DeleteCategorieFaqRequestAction;
use App\Controller\CategorieFaq\GetCategorieFaqRequestAction;
use App\Controller\CategorieFaq\ListCategorieFaqRequestAction;
use App\Controller\CategorieFaq\UpdateCategorieFaqRequestAction;
use App\Repository\CategorieFaqRepository;
use Doctrine\ORM\Mapping as ORM;

#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/categorie-faq/by-id/{id}',
        controller: GetCategorieFaqRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/categorie-faq/list',
        controller: ListCategorieFaqRequestAction::class),
        new Post(uriTemplate: '/auth/categorie-faq/create',
        controller: CreateCategorieFaqRequestAction::class,
        input: CategorieFaq::class),
        new Put(uriTemplate: '/auth/categorie-faq/modify/{id}',
        controller: UpdateCategorieFaqRequestAction::class,
        input: CategorieFaq::class),
        new Get(uriTemplate: '/auth/categorie-faq/delete/{id}',
        controller: DeleteCategorieFaqRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
#[ORM\Entity(repositoryClass: CategorieFaqRepository::class)]
#[ORM\Table(name: '`categorie_faq`')]
class CategorieFaq extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 128)]
    private ?string $libelle = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getLibelle(): ?string
    {
        return $this->libelle;
    }

    public function setLibelle(string $libelle): static
    {
        $this->libelle = $libelle;

        return $this;
    }

}
