<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Page\CreatePageRequestAction;
use App\Controller\Page\DeletePageRequestAction;
use App\Controller\Page\GetPageRequestAction;
use App\Controller\Page\ListPageRequestAction;
use App\Controller\Page\UpdatePageRequestAction;
use App\Payload\PagePaylod;
use App\Repository\PageRepository;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\String\Slugger\SluggerInterface;

#[ORM\Entity(repositoryClass: PageRepository::class)]
#[ApiResource(
    routePrefix: '/auth/page',
    operations: [
        new Get(uriTemplate: '/white-api/page/by-id/{id}',
        controller: GetPageRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/page/list',
        controller: ListPageRequestAction::class),
        new Post(uriTemplate: '/auth/page/create',
        controller: CreatePageRequestAction::class,
        input: PagePaylod::class),
        new Put(uriTemplate: '/auth/page/modify/{id}',
        controller: UpdatePageRequestAction::class,
        input: PagePaylod::class),
        new Get(uriTemplate: '/auth/page/delete/{id}',
        controller: DeletePageRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Page  extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $titre = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $contenu = null;

    #[ORM\Column(nullable: true)]
    private ?\DateTimeImmutable $publishedAt = null;

    #[ORM\Column]
    private ?bool $estPubliser = null;

    #[ORM\Column]
    private ?bool $estArchiver = null;

    #[ORM\Column(length: 255)]
    private ?string $slug = null;

    #[ORM\Column(length: 255)]
    private ?string $auteur = null;

    #[ORM\ManyToOne(targetEntity: MediaObject::class)]
    #[ORM\JoinColumn(nullable: true)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?MediaObject $mediaObject = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function computeSlug(SluggerInterface $slugger)
    {
        if (!$this->slug || '-' === $this->slug) {
            $this->slug = (string) $slugger->slug((string) $this->getTitre())->lower();
        }
    }

    public function getTitre(): ?string
    {
        return $this->titre;
    }

    public function setTitre(string $titre): static
    {
        $this->titre = $titre;

        return $this;
    }

    public function getContenu(): ?string
    {
        return $this->contenu;
    }

    public function setContenu(?string $contenu): static
    {
        $this->contenu = $contenu;

        return $this;
    }

    public function getPublishedAt(): ?\DateTimeImmutable
    {
        return $this->publishedAt;
    }

    public function setPublishedAt(?\DateTimeImmutable $publishedAt): static
    {
        $this->publishedAt = $publishedAt;

        return $this;
    }

    public function isEstPubliser(): ?bool
    {
        return $this->estPubliser;
    }

    public function setEstPubliser(bool $estPubliser): static
    {
        $this->estPubliser = $estPubliser;

        return $this;
    }

    public function isEstArchiver(): ?bool
    {
        return $this->estArchiver;
    }

    public function setEstArchiver(bool $estArchiver): static
    {
        $this->estArchiver = $estArchiver;

        return $this;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(string $slug): static
    {
        $this->slug = $slug;

        return $this;
    }

    public function getAuteur(): ?string
    {
        return $this->auteur;
    }

    public function setAuteur(string $auteur): static
    {
        $this->auteur = $auteur;

        return $this;
    }

    public function getMediaObject(): ?MediaObject
    {
        return $this->mediaObject;
    }

    public function setMediaObject(?MediaObject $mediaObject): static
    {
        $this->mediaObject = $mediaObject;

        return $this;
    }

}
