<?php

namespace App\Entity;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\ApiResource;
use ApiPlatform\Metadata\Get;
use ApiPlatform\Metadata\GetCollection;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use App\Controller\Publication\CreatePublicationRequestAction;
use App\Controller\Publication\DeletePublicationRequestAction;
use App\Controller\Publication\GetPublicationRequestAction;
use App\Controller\Publication\ListPublicationRequestAction;
use App\Controller\Publication\UpdatePublicationRequestAction;
use App\Payload\PublicationPaylod;
use App\Repository\PublicationRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\String\Slugger\SluggerInterface;

#[ORM\Entity(repositoryClass: PublicationRepository::class)]
#[ApiResource(
    routePrefix: '',
    operations: [
        new Get(uriTemplate: '/white-api/publication/by-id/{id}',
        controller: GetPublicationRequestAction::class),
        new GetCollection(uriTemplate: '/white-api/publication/list',
        controller: ListPublicationRequestAction::class),
        new Post(uriTemplate: '/auth/publication/create',
        controller: CreatePublicationRequestAction::class,
        input: PublicationPaylod::class),
        new Put(uriTemplate: '/auth/publication/modify/{id}',
        controller: UpdatePublicationRequestAction::class,
        input: PublicationPaylod::class),
        new Get(uriTemplate: '/auth/publication/delete/{id}',
        controller: DeletePublicationRequestAction::class),
     ],
     formats: [
        'json' =>    ['application/json'],
        'xml' =>     ['application/xml', 'text/xml'],
     ],
     paginationEnabled: false,
     order: ['createdAt' => 'DESC', 'libelle' => 'ASC'],
)]
class Publication  extends Commun 
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(length: 255)]
    private ?string $titre = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $contenu = null;

    #[ORM\Column(nullable: true)]
    private ?\DateTimeImmutable $publishedAt = null;

    #[ORM\Column]
    private ?bool $estPubliser = null;

    #[ORM\Column]
    private ?bool $estArchiver = null;

    #[ORM\Column(length: 255)]
    private ?string $slug = null;

    #[ORM\Column(length: 255)]
    private ?string $auteur = null;

    #[ORM\ManyToOne(targetEntity: CategoriePublication::class)]
    #[ORM\JoinColumn(nullable: false)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?CategoriePublication $categoriePublication = null;

    #[ORM\ManyToOne(targetEntity: MediaObject::class)]
    #[ORM\JoinColumn(nullable: true)]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private ?MediaObject $mediaObject = null;

    #[ORM\Column]
    private ?bool $sendByNewLetter = null;

    #[ORM\Column]
    private ?bool $estAlreadySentNewLetter = null;

    #[ORM\ManyToMany(targetEntity: Tag::class, inversedBy: 'publications', cascade: ['persist'])]
    #[ApiProperty(writable: false, writableLink: true, readableLink: true)]
    private Collection $tags;

    public function __construct()
    {
        $this->tags = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function computeSlug(SluggerInterface $slugger)
    {
        if (!$this->slug || '-' === $this->slug) {
            $this->slug = (string) $slugger->slug((string) $this->getTitre())->lower();
        }
    }

    public function getTitre(): ?string
    {
        return $this->titre;
    }

    public function setTitre(string $titre): static
    {
        $this->titre = $titre;

        return $this;
    }

    public function getContenu(): ?string
    {
        return $this->contenu;
    }

    public function setContenu(?string $contenu): static
    {
        $this->contenu = $contenu;

        return $this;
    }

    public function getPublishedAt(): ?\DateTimeImmutable
    {
        return $this->publishedAt;
    }

    public function setPublishedAt(?\DateTimeImmutable $publishedAt): static
    {
        $this->publishedAt = $publishedAt;

        return $this;
    }

    public function isEstPubliser(): ?bool
    {
        return $this->estPubliser;
    }

    public function setEstPubliser(bool $estPubliser): static
    {
        $this->estPubliser = $estPubliser;

        return $this;
    }

    public function isEstArchiver(): ?bool
    {
        return $this->estArchiver;
    }

    public function setEstArchiver(bool $estArchiver): static
    {
        $this->estArchiver = $estArchiver;

        return $this;
    }

    public function getSlug(): ?string
    {
        return $this->slug;
    }

    public function setSlug(string $slug): static
    {
        $this->slug = $slug;

        return $this;
    }

    public function getAuteur(): ?string
    {
        return $this->auteur;
    }

    public function setAuteur(string $auteur): static
    {
        $this->auteur = $auteur;

        return $this;
    }

    public function getCategoriePublication(): ?CategoriePublication
    {
        return $this->categoriePublication;
    }

    public function setCategoriePublication(?CategoriePublication $categoriePublication): static
    {
        $this->categoriePublication = $categoriePublication;

        return $this;
    }

    public function getMediaObject(): ?MediaObject
    {
        return $this->mediaObject;
    }

    public function setMediaObject(?MediaObject $mediaObject): static
    {
        $this->mediaObject = $mediaObject;

        return $this;
    }

    public function isSendByNewLetter(): ?bool
    {
        return $this->sendByNewLetter;
    }

    public function setSendByNewLetter(bool $sendByNewLetter): static
    {
        $this->sendByNewLetter = $sendByNewLetter;

        return $this;
    }

    public function isEstAlreadySentNewLetter(): ?bool
    {
        return $this->estAlreadySentNewLetter;
    }

    public function setEstAlreadySentNewLetter(bool $estAlreadySentNewLetter): static
    {
        $this->estAlreadySentNewLetter = $estAlreadySentNewLetter;

        return $this;
    }

    /**
     * @return Collection<int, Tag>
     */
    public function getTags(): Collection
    {
        return $this->tags;
    }

    public function addTag(Tag $tag): static
    {
        if (!$this->tags->contains($tag)) {
            $this->tags->add($tag);
            $tag->addPublication($this);
        }

        return $this;
    }

    public function removeTag(Tag $tag): static
    {
        if ($this->tags->removeElement($tag)) {
            $tag->removePublication($this);
        }

        return $this;
    }
}
